@@ -21,6 +21,7 @@ from selenium import webdriver
 from selenium.webdriver import ActionChains
 from selenium.webdriver.chrome.options import Options
 import platform
+import pathlib
 
 from recurrent import Recurrent
 
@@ -98,7 +99,8 @@ class Controller:
     def shorteningService(self):
         url = self.url
         short_url, long_url = url, ''
-        test_read = open(r'./data/shortening_services.txt', 'r')
+        shortening_services = str(pathlib.Path(__file__).parent.absolute()) + r'/data/shortening_services.txt'
+        test_read = open(shortening_services, 'r')
         
         havingIP = Controller.havingIPAddress(self)
         
@@ -182,7 +184,8 @@ class Controller:
             if(len(issued_by.split(" "))>1):
                 CA = issued_by.split(" ")[0] + " " + issued_by.split(" ")[1] 
             
-            SSL_read = open(r'./data/ssl_list.txt','r')
+            ssl_list = str(pathlib.Path(__file__).parent.absolute()) + r'/data/ssl_list.txt'
+            SSL_read = open(ssl_list,'r')
             
             if((issued_by.split()[0] or CA)in SSL_read.read()):
                 return 0
@@ -190,7 +193,8 @@ class Controller:
                 return 1
     
     def domainRegistration(self):
-        test_read = open(r'./data/edu_domains.txt', 'r')
+        edu_domains = str(pathlib.Path(__file__).parent.absolute()) + r'/data/edu_domains.txt'
+        test_read = open(edu_domains, 'r')
         parts = self.parts
         domain_name = parts.netloc
         if('.edu' in domain_name):
